
GET
  FILE='C:\WHO\SPSS\HH.sav'.
DATASET NAME DataSet3 WINDOW=FRONT.

compute sampled = 1.


recode HH11 (1,2,3,8 = 1) (else = 0) into occupied.

recode HH11 (1 = 1) (else = 0) into complete.

compute total = 1.
variable label total "Total".
value label total 1 "".

aggregate outfile = 'tmp1.sav'
  /break   = Hdiv
  /hhsamp  = sum(sampled)
  /hhoccup = sum(occupied)
  /hhcomp  = sum(complete)
  /women   = sum(HH14)
  /cwomen  = sum(HH16)
  /kids    = sum(HH15).
  

aggregate outfile = 'tmp2.sav'
  /break   = HH7
  /hhsamp  = sum(sampled)
  /hhoccup = sum(occupied)
  /hhcomp  = sum(complete)
  /women   = sum(HH14)
  /cwomen  = sum(HH16)
  /kids    = sum(HH15).

aggregate outfile = 'tmp3.sav'
  /break   = total
  /hhsamp  = sum(sampled)
  /hhoccup = sum(occupied)
  /hhcomp  = sum(complete)
  /women   = sum(HH14)
  /cwomen  = sum(HH16)
  /kids    = sum(HH15).  

get file = 'tmp1.sav'.

add files
  /file = *
  /file = 'tmp2.sav'
  /file = 'tmp3.sav'.

variable label
  hhsamp   "Sampled households"
  /hhoccup "Occupied households"
  /hhcomp  "Interviewed households"
  /women   "Number of fistula questionnaire completed"
  /cwomen  "Total number of women aged 15 - 49"
  /kids    "Total number of people in household (Household size)"
  
.

compute hhrr = (hhcomp/hhoccup)*100.
variable label hhrr "Household response rate".



tables
  /format = zero
  /observation = hhsamp hhoccup hhcomp hhrr women cwomen kids  
  /table = hhsamp + hhoccup + hhcomp + hhrr + women + cwomen + kids BY HH7 + Hdiv + total
  /statistics
    maximum(hhsamp '' (f7.0))
    maximum(hhoccup '' (f7.0))
    maximum(hhcomp '' (f7.0))
    maximum(hhrr '' (f7.1))
    maximum(women '' (f7.0))
    maximum(cwomen'' (f7.0))
    maximum(kids '' (f7.0))
    /title
    "Table HH.1: Results of household and individual interviews" 
		"Numbers of households, Fistula women, women aged 15-49, "+
		"household size and household response rate "+
		"Fistula Survey, The Gambia, 2006".

new file.

*delete working files.
erase file = 'tmp1.sav'.
erase file = 'tmp2.sav'.
erase file = 'tmp3.sav'.


*************************************************************


GET
  FILE='C:\WHO\SPSS\HL.sav'.
DATASET NAME DataSet6 WINDOW=FRONT.


* Table of Frequencies.
TABLES
  /FTOTAL $t 'Total'
  /FORMAT BLANK MISSING('.') /TABLES
  (LABELS) + $t BY
  NHL1
  /STATISTICS COUNT ((F6) 'Women aged 15-49' )
    CPCT ((F7.1) 'Percent' )  /TITLE  'Table X: Women aged 15-49 by five - year age'+
 ' group ' /CAPTION  'Fistula  Survey, December, 2006'.


*******************************************************************

GET
  FILE='C:\WHO\SPSS\HL.sav'.
DATASET NAME DataSet6 WINDOW=FRONT.


* Table of Frequencies.
TABLES
  /FTOTAL $t 'Total'
  /FORMAT BLANK MISSING('.') /TABLES
  (LABELS) + $t BY
  Hdiv
  /STATISTICS COUNT ((F6) 'Women aged 15-49' )
    CPCT ((F7.1) 'Percent' )  /TITLE  'Table X: Women aged 15-49 by health'+
 ' division ' /CAPTION  'Fistula  Survey, December, 2006'.

******************************************************************
GET
  FILE='C:\WHO\SPSS\HL.sav'.
DATASET NAME DataSet6 WINDOW=FRONT.


* Table of Frequencies.
TABLES
  /FTOTAL $t 'Total'
  /FORMAT BLANK MISSING('.') /TABLES
  (LABELS) + $t BY
  HH5
  /STATISTICS COUNT ((F6) 'Women aged 15-49' )
    CPCT ((F7.1) 'Percent' )  /TITLE  'Table X: Women aged 15-49 by PHC/NON PHC'+
 ' area ' /CAPTION  'Fistula  Survey, December, 2006'.

*******************************************************************


GET
  FILE='C:\WHO\SPSS\HL.sav'.
DATASET NAME DataSet6 WINDOW=FRONT.

* Table of Frequencies.
TABLES
  /FTOTAL $t 'Total'
  /FORMAT BLANK MISSING('.') /TABLES
  (LABELS) + $t BY
  HH7
  /STATISTICS COUNT ((F6) 'Women aged 15-49' )
    CPCT ((F7.1) 'Percent' )  /TITLE  'Table X: Women aged 15-49 in urban and rural'+
 ' areas ' /CAPTION  'Fistula  Survey, December, 2006'.

******************************************************************

GET
  FILE='C:\WHO\SPSS\HH.sav'.
DATASET NAME DataSet5 WINDOW=FRONT.


* Table of Frequencies.
TABLES
  /FTOTAL $t 'Total'
  /FORMAT BLANK MISSING('.') /TABLES
  (LABELS) + $t BY
  HH19
  /STATISTICS COUNT ((F6) 'No. of households' )
    CPCT ((F7.1) 'Percent' )  /TITLE  'Table X: Households that reported pregnant girls less than 15 years'+
 ' of age' /CAPTION  'Fistula  Survey, December, 2006'.




*********************************************************************

* Table of Frequencies.
TABLES
  /FTOTAL $t 'Total'
  /FORMAT BLANK MISSING('.') /TABLES
  (LABELS) + $t BY
  HH22
  /STATISTICS COUNT ((F6) 'No of households' )
    CPCT ((F7.1) 'Percent' )  /TITLE  'Table X: Persons in households taking decision'+
 ' for women to go to labour' /CAPTION  'Fistula  Survey, December, 2006'.



***********************************************************************


GET
  FILE='C:\WHO\SPSS\HL.sav'.
DATASET NAME DataSet5 WINDOW=FRONT.

USE ALL.
COMPUTE filter_$=(hl10 = 1).
VARIABLE LABEL filter_$ 'hl10 = 1 (FILTER)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE .

compute cases = 1.

*recode HH11 (1 = 1) (else = 0) into complete.

tables
  /format = zero
  /observation =  cases
   /ftotal  tot1 "Total"     
   /table = Hdiv + cases by Hl11 + Hl11B + HL11C+HL11D+HL11E+ tot1   
  /statistics
      cpct(Hdiv 'Percent' (f2.1):Hdiv)
      count(cases (f2))
   /title
    "Table TBx: Percent distribution of ever pregnant woman 15-49 years old, in each health division, who had antenatal care by " 
		"knowledge of pregnancy complication that warrants going to health institution,  The Gambia, 2006"
/caption
    "Source: Fistula survey, December,  2006".




****************************************************************


GET
  FILE='C:\WHO\SPSS\HL.sav'.
DATASET NAME DataSet5 WINDOW=FRONT.

USE ALL.
COMPUTE filter_$=(hl10 = 1).
VARIABLE LABEL filter_$ 'hl10 = 1 (FILTER)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE .

compute cases = 1.

*recode HH11 (1 = 1) (else = 0) into complete.

tables
  /format = zero
  /observation =  cases
   /ftotal  tot1 "Total"     
   /table = Hdiv + cases by  HL11F+ HL11G+ HL11H+ HL11I+HL11J+tot1   
  /statistics
      cpct(Hdiv 'Percent' (f2.1):Hdiv)
      count(cases (f2))
   /title
    "Table TBx: Percent distribution of ever pregnant woman 15-49 years old, in each health division, who had antenatal care by " 
		"knowledge of pregnancy complication that warrants going to health institution,  The Gambia, 2006"
/caption
    "Source: Fistula survey, December,  2006".






*****************************************************************


GET
  FILE='C:\WHOTB\TB.sav'.
DATASET NAME DataSet2 WINDOW=FRONT.

 
compute tr = 0.
if (tb39b = 1)tr = 1.
if (tb39b = 2)tr = 1.
if (tb39b = 3)tr = 1.
if (tb39b = 4)tr = 1.
if (tb39b = 5)tr = 1.
if (tb39b = 6)tr = 1.
if (tb39b = 0)tr = 2.
if (tb39b = 9)tr = 2.


USE ALL.
COMPUTE filter_$=(tr = 1).
VARIABLE LABEL filter_$ 'tr = 1 (FILTER)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE .



* General Tables.
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000001 "Total"
  /TABLE= TB3B + $t000001  BY tb30 + tb31 + tb32 + tb33     
    /STATISTICS
  cpct( TB3B( F5.1 ) 'Percent':TB3B )
  count( TB3B( F5.0 ))
  count( $t000001( F5.0 ))
  cpct( $t000001( F5.1 ) 'Percent':TB3B )
   /title
    "Table TB2: Percent distribution of trained traditional birth attendants by Advice they provide" 
		"to mothers after child birth and Health Division, The Gambia, 2006"
/caption
    "Source: Fistula survey, December,  2006".




*****************************************************

GET
  FILE='C:\WHOTB\TB.sav'.
DATASET NAME DataSet2 WINDOW=FRONT.

 
compute tr = 0.
if (tb39b = 1)tr = 1.
if (tb39b = 2)tr = 1.
if (tb39b = 3)tr = 1.
if (tb39b = 4)tr = 1.
if (tb39b = 5)tr = 1.
if (tb39b = 6)tr = 1.
if (tb39b = 0)tr = 2.
if (tb39b = 9)tr = 2.


USE ALL.
COMPUTE filter_$=(tr = 1).
VARIABLE LABEL filter_$ 'tr = 1 (FILTER)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE .



* General Tables.
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000001 "Total"
  /TABLE= TB3B + $t000001  BY  tb34 + tb35 + tb36 + tb37    
    /STATISTICS
  cpct( TB3B( F5.1 ) 'Percent':TB3B )
  count( TB3B( F5.0 ))
  count( $t000001( F5.0 ))
  cpct( $t000001( F5.1 ) 'Percent':TB3B )
   /title
    "Table TB2: Percent distribution of trained traditional birth attendants by Advice they provide" 
		"to mothers after child birth and Health Division, The Gambia, 2006"
/caption
    "Source: Fistula survey, December,  2006".



**********************************************************




GET
  FILE='C:\WHOTB\TB.sav'.
DATASET NAME DataSet2 WINDOW=FRONT.


 
compute tr = 0.
if (tb39b = 1)tr = 1.
if (tb39b = 2)tr = 1.
if (tb39b = 3)tr = 1.
if (tb39b = 4)tr = 1.
if (tb39b = 5)tr = 1.
if (tb39b = 6)tr = 1.
if (tb39b = 0)tr = 2.
if (tb39b = 9)tr = 2.

USE ALL.
COMPUTE filter_$=(tr = 2).
VARIABLE LABEL filter_$ 'tr = 2 (FILTER)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE .


* General Tables.
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000001 "Total"
  /TABLE= TB3B + $t000001  BY tb30 + tb31 + tb32 + tb33     
    /STATISTICS
  cpct( TB3B( F5.1 ) 'Percent':TB3B )
  count( TB3B( F5.0 ))
  count( $t000001( F5.0 ))
  cpct( $t000001( F5.1 ) 'Percent':TB3B )
   /title
    "Table TB2: Percent distribution of untrained traditional birth attendants by Advice they provide" 
		"to mothers after child birth and Health Division, The Gambia, 2006"
/caption
    "Source: Fistula survey, December,  2006".




*****************************************************

GET
  FILE='C:\WHOTB\TB.sav'.
DATASET NAME DataSet2 WINDOW=FRONT.




compute tr = 0.
if (tb39b = 1)tr = 1.
if (tb39b = 2)tr = 1.
if (tb39b = 3)tr = 1.
if (tb39b = 4)tr = 1.
if (tb39b = 5)tr = 1.
if (tb39b = 6)tr = 1.
if (tb39b = 0)tr = 2.
if (tb39b = 9)tr = 2.



USE ALL.
COMPUTE filter_$=(tr = 2).
VARIABLE LABEL filter_$ 'tr = 2 (FILTER)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE .



* General Tables.
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000001 "Total"
  /TABLE= TB3B + $t000001  BY  tb34 + tb35 + tb36 + tb37    
    /STATISTICS
  cpct( TB3B( F5.1 ) 'Percent':TB3B )
  count( TB3B( F5.0 ))
  count( $t000001( F5.0 ))
  cpct( $t000001( F5.1 ) 'Percent':TB3B )
   /title
    "Table TB2: Percent distribution of untrained traditional birth attendants by Advice they provide" 
		"to mothers after child birth and Health Division, The Gambia, 2006"
/caption
    "Source: Fistula survey, December,  2006".



*************************************************************



GET
  FILE='C:\WHO\SPSS\HL.sav'.
DATASET NAME DataSet5 WINDOW=FRONT.

tables
  /format = zero
   /ftotal  tot1 "Total"     
   /table = Hdiv + tot1 by HL10 + tot1  
  /statistics
      count(HL10 'No. of women' (f6.0))
   /title
    "Table TBx: Women who have antenatal care during pregnancy by division" 
		"The Gambia, 2006"
/caption
    "Source: Fistula survey, December,  2006".



**********************************************************


* General Tables.
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000001 "Total"
  /TABLE=Hdiv + $t000001  BY HL9A > (STATISTICS) + HL9B > (STATISTICS) + HL9C
  > (STATISTICS) + HL9D > (STATISTICS)
  /STATISTICS
  count( Hdiv( F5.0 ))
   /title
    "Table TBx: Women by place of care during abortion and still birth by division" 
		"The Gambia, 2006"
/caption
    "Source: Fistula survey, December,  2006".

***********************************************************************

* General Tables.
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000001 "Total"
  /TABLE=Hdiv + $t000001  BY HL9A > (STATISTICS) + HL9B > (STATISTICS) + HL9C
  > (STATISTICS) + HL9D > (STATISTICS)
  /STATISTICS
  cpct( Hdiv( F5.1 ) 'Percent':Hdiv )
   /title
    "Table TBx: Percent of Women who have antenatal care during pregnancy by division" 
		"The Gambia, 2006"
/caption
    "Source: Fistula survey, December,  2006".


*****************************************************************************


GET
  FILE='C:\WHOHF\HF.sav'.
DATASET NAME DataSet6 WINDOW=FRONT.

* Basic Tables.
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION FP1 FP2 FP3 FP4 FP5 FP6 FP7 FP8 FP9
  /FTOTAL $t 'Total'
  /TABLES (FP1 + FP2 + FP3 + FP4 + FP5 + FP6 + FP7 + FP8 + FP9)
  BY (HE3 > (STATISTICS) +  $t )
  /STATISTICS
  sum( 'Number' )
  spct( ( F5.1 ) 'Percent')
   /title
    "Table TBx: Family planning method mix by facility type" 
		"The Gambia, 2006"
/caption
    "Source: Fistula survey, December,  2006".



*********************************

* Basic Tables.
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION FP1 FP2 FP3 FP4 FP5 FP6 FP7 FP8 FP9
  /FTOTAL $t 'Total'
  /TABLES (FP1 + FP2 + FP3 + FP4 + FP5 + FP6 + FP7 + FP8 + FP9)
  BY (HE4 > (STATISTICS) +  $t )
  /STATISTICS
  sum( 'Number' )
  spct( ( F5.1 ) 'Percent')
   /title
    "Table TBx: Family planning method mix by facility administration" 
		"The Gambia, 2006"
/caption
    "Source: Fistula survey, December,  2006".

*********************************************************


****************************************************************************


GET
  FILE='C:\WHOHF\HF.sav'.
DATASET NAME DataSet6 WINDOW=FRONT.

* Basic Tables.
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION  AC26 AC1 AC2 AC3 AC4 AC5 AC6 AC7 AC8 AC9 AC10 AC11 AC12 AC13
  /FTOTAL $t 'Total'
  /TABLES (AC26+ AC1+ AC2+ AC3+ AC4+ AC5 +AC6+ AC7+ AC8+ AC9 +AC10 +AC11+ AC12 +AC13)
  BY (HE3 > (STATISTICS) +  $t )
  /STATISTICS
  sum( 'Number' )
  spct( ( F5.1 ) 'Percent')
   /title
    "Table TBx: Maternal services provided by facilities past 6 months" 
		"The Gambia, 2006"
/caption
    "Source: Fistula survey, December,  2006".


**********************************************************ADDITIONAL STARTED HERE*******


GET
  FILE='C:\WHOHF\HFWIVES2.sav'.
DATASET NAME DataSet3 WINDOW=FRONT.

*COMPREHENSIVE EMOC FACILITIES

USE ALL.
COMPUTE filter_$=(HE1 = 47 or HE1 = 36 or HE1 = 49 or HE1 = 48 or HE1 = 24 or
  HE1 = 13 or HE1 = 17 or HE1 = 9 or HE1 = 10).
VARIABLE LABEL filter_$ 'HE1 = 47 or HE1 = 36 or HE1 = 49 or HE1 = 48 or HE1'+
 ' = 24 or HE1 = 13 or HE1 = 17 or HE1 = 9 or HE1 = 10 (FILTER)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE .



EXECUTE.
* Basic Tables.
TEMPORARY.
NUMERIC T0000000.
LEAVE T0000000.
VARIABLE LABEL T0000000 'Table Total'.
VALUE LABELS T0000000 0 ' '.
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION OC1
  /FTOTAL $t 'Group Total'
  /TABLES (HE1 > OC1 +  $t  + T0000000 > OC1)
  BY (MD1 > (STATISTICS) +  $t  + T0000000 > (STATISTICS))
  /STATISTICS
  sum('Number' )
   /title
    "Table TBx: Staffing situation in  EMOC comprehensive facilities" 
		"The Gambia, 2006"
/caption
    "Source: Fistula survey, December,  2006".




GET
  FILE='C:\WHOHF\HFWIVES2.sav'.
DATASET NAME DataSet3 WINDOW=FRONT.


*FACILITY OPERATOR AS BASICS


USE ALL.
COMPUTE filter_$=(HE1 = 40 or HE1 = 44 or HE1 = 37 or HE1 = 45 or HE1 = 21or
  HE1 = 11 or HE1 = 2 or HE1 = 28 or HE1 = 34 or HE1 = 33).
VARIABLE LABEL filter_$ 'HE1 = 40 or HE1 = 44 or HE1 = 37 or HE1 = 45 or HE1'+
 ' = 21or HE1 = 11 or HE1 = 2 or HE1 = 28 or HE1 = 34 or HE... (FILTER)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE .



EXECUTE.
* Basic Tables.
TEMPORARY.
NUMERIC T0000000.
LEAVE T0000000.
VARIABLE LABEL T0000000 'Table Total'.
VALUE LABELS T0000000 0 ' '.
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION OC1
  /FTOTAL $t 'Group Total'
  /TABLES (HE1 > OC1 +  $t  + T0000000 > OC1)
  BY (MD1 > (STATISTICS) +  $t  + T0000000 > (STATISTICS))
  /STATISTICS
  sum('Number' )
   /title
    "Table TBx: Staffing situation in EMOC Basic facilities" 
		"The Gambia, 2006"
/caption
    "Source: Fistula survey, December,  2006".



***************************************************************************************


GET
  FILE='C:\WHOHF\HF.sav'.
DATASET NAME DataSet6 WINDOW=FRONT.

*COMPREHENSIVE EMOC FACILITIES

USE ALL.
COMPUTE filter_$=(HE1 = 47 or HE1 = 36 or HE1 = 49 or HE1 = 48 or HE1 = 24 or
  HE1 = 13 or HE1 = 17 or HE1 = 9 or HE1 = 10).
VARIABLE LABEL filter_$ 'HE1 = 47 or HE1 = 36 or HE1 = 49 or HE1 = 48 or HE1'+
 ' = 24 or HE1 = 13 or HE1 = 17 or HE1 = 9 or HE1 = 10 (FILTER)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE .



* Basic Tables.
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION IF16 IF17 IF18 IF19 IF20 IF21 IF22 IF23 IF24 IF25 IF26
  /FTOTAL $t 'Total'
  /TABLES (IF16+ IF17+ IF18+ IF19+ IF20+ IF21+ IF22+ IF23+ IF24+ IF25+ IF26)
  BY (HE1 > (STATISTICS) +  $t )
  /STATISTICS
  sum( 'Number' )
   /title
    "Table TBx: Basic equipment situation in EMOC comprehensive facility" 
		"The Gambia, 2006"
/caption
    "Source: Fistula survey, December,  2006".



************************************************************************************


GET
  FILE='C:\WHOHF\HF.sav'.
DATASET NAME DataSet6 WINDOW=FRONT.


*FACILITY OPERATOR AS BASICS

EXECUTE.
USE ALL.
COMPUTE filter_$=(HE1 = 40  or  HE1 = 44 or HE1 = 37  or  HE1 = 45 or HE1 =
  21  or  HE1 = 11 or HE1 = 2  or  HE1 = 28 or HE1 = 34  or HE1 = 33).
VARIABLE LABEL filter_$ 'HE1 = 40  or  HE1 = 44 or HE1 = 37  or  HE1 = 45 or'+
 ' HE1 = 21  or  HE1 = 11 or HE1 = 2  or  HE1 = 28 or HE1 = 34 or HE1 =... (FILTER)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE .


* Basic Tables.
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION IF16 IF17 IF18 IF19 IF20 IF21 IF22 IF23 IF24 IF25 IF26
  /FTOTAL $t 'Total'
  /TABLES (IF16+ IF17+ IF18+ IF19+ IF20+ IF21+ IF22+ IF23+ IF24+ IF25+ IF26)
  BY (HE1 > (STATISTICS) +  $t )
  /STATISTICS
  sum( 'Number' )
   /title
    "Table TBx: Basic equipment situation in EMOC basic facility" 
		"The Gambia, 2006"
/caption
    "Source: Fistula survey, December,  2006".


***********************************************************************************************************************



GET
  FILE='C:\WHOTB\TB.sav'.
DATASET NAME DataSet2 WINDOW=FRONT.


 
compute tr = 0.
if (tb39b = 1)tr = 1.
if (tb39b = 2)tr = 1.
if (tb39b = 3)tr = 1.
if (tb39b = 4)tr = 1.
if (tb39b = 5)tr = 1.
if (tb39b = 6)tr = 1.
if (tb39b = 0)tr = 2.
if (tb39b = 9)tr = 2.

Value label  TR
             1     "Trained TBA"
	 2     "Untrained". 	

Freq  trained


* General Tables.
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000001 "Total"
  /TABLE=tb6+ tb7+ tb8+ tb9+ tb10+ tb11+ tb12+ tb13+ tb14+ tb15   BY tr +   $t000001
  /STATISTICS
  cpct( tr( F5.1 ) 'Percent':tr )
  count( tr( F5.0 ))
  count( $t000001( F5.0 ))
  cpct( $t000001( F5.1 ) 'Percent':tr )
   /title
    "Table TB2: Percent distribution of trained and untrained traditional birth attendants by danger signs in delivery and pregnancy that warrant refering" 
		"a woman to a health facility, The Gambia, 2006"
/caption
    "Source: Fistula survey, December,  2006".




***************************************************************


GET
  FILE='C:\WHOHF\HF.sav'.
DATASET NAME DataSet1 WINDOW=FRONT.



* Basic Tables.
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION DR1 DR2 DR3 DR4 DR5 DR6 DR7
  /FTOTAL $t 'Total'
  /TABLES (DR1+ DR2+ DR3+ DR4+ DR5+ DR6+ DR7)
  BY (HE3 > (STATISTICS) +  $t )
  /STATISTICS
  sum( 'Number' )
  spct( ( F5.1 ) 'Percent')
   /title
    "Table TBx: Births, Maternal and perinatal deaths, and still births in in facilities by facility type" 
		"The Gambia, 2006"
/caption
    "Source: Fistula survey, December,  2006".


**************************************************************








*******************************************************************************************************************************


GET
  FILE='C:\WHOHF\HFWIVES2.sav'.
DATASET NAME DataSet5 WINDOW=FRONT.

compute total = 1.
variable label total "Total".
value label total 1 "Total".
             
 variable label  MD1  'Number of personnel'.

aggregate outfile = 'tmp1.sav'
    /break   = MD1
  /Occu  = sum(OC1).

 
aggregate outfile = 'tmp3.sav'
  /break   = total  
  /Occu  = sum(OC1).
 
get file = 'tmp1.sav'.

add files
  /file = *
 /file = 'tmp3.sav'.

compute nprop = (Occu/1000).
Execute.


tables
  /format = zero
  /observation =   Occu nprop
  /table = MD1+ Total by Occu+nprop  
  /statistics
  sum(Occu (F8) 'Number of personnel')
  sum(nprop (F8.7) 'Medical Personnel per 1000 target population')
   /title
    "Table TBx: Status of maternal health personnel by position in health facilities" 
		"The Gambia, 2006"
/caption
    "Source: Fistula survey, December,  2006".




********************************************************************************************************************************



GET
  FILE='C:\WHOTR\FISTULA1.sav'.
DATASET NAME DataSet11 WINDOW=FRONT.

FREQUENCIES
  VARIABLES=TR6 TR8 E6 E8 S2 S3 S4 S5B S7 S8 S9 S10 S12 FH1 FH2 FH3 FH4 FH6 FH7 FH9
  FH10 F10B F10C F10D F10E F11 F12 F14 F15 F16 F23 F24 F27 F30 F32 F33 F34 F35
  F36 F37 F39 F41 .


  */STATISTICS=STDDEV MEAN MODE SUM
  */ORDER=  ANALYSIS .



FREQUENCIES
  VARIABLES=S2 S4 FH2 FH3 FH4 FH10 F10B F10C F10D F10E
  /STATISTICS=STDDEV MEAN MODE SUM
  /ORDER=  ANALYSIS .


**************************************************************************************************************8



